| Type: | Package |
| Title: | Plot Adjusted Kaplan-Meier Estimates from a Landmark Time |
| Version: | 0.2.0 |
| Description: | Plots contextual landmark Kaplan-Meier curves. An extension of the 'survminer::ggsurvplot()' function that allows the specification of a landmark time and an optional label. The period before the landmark is displayed as a pooled survival curve, while curves beyond the landmark are presented according to the groups defined in the supplied 'survival::survfit' object. |
| License: | GPL (≥ 3) |
| Encoding: | UTF-8 |
| URL: | https://github.com/CStats/landmarked |
| Imports: | dplyr, ggplot2, survival, survminer |
| RoxygenNote: | 7.3.3 |
| Suggests: | knitr, rmarkdown, testthat (≥ 3.0.0) |
| Depends: | R (≥ 4.1.0) |
| Config/testthat/edition: | 3 |
| VignetteBuilder: | knitr |
| NeedsCompilation: | no |
| Packaged: | 2026-09-08 10:31:38 UTC; christopherb |
| Author: | Chris Brown |
| Maintainer: | Chris Brown <c.brown@sydney.edu.au> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-15 14:30:02 UTC |
landmarked: Plot Adjusted Kaplan-Meier Estimates from a Landmark Time
Description
Plots contextual landmark Kaplan-Meier curves. An extension of the 'survminer::ggsurvplot()' function that allows the specification of a landmark time and an optional label. The period before the landmark is displayed as a pooled survival curve, while curves beyond the landmark are presented according to the groups defined in the supplied 'survival::survfit' object.
Author(s)
Maintainer: Chris Brown c.brown@sydney.edu.au (ORCID) [copyright holder]
See Also
Useful links:
Recreate a dataset from a survfit object
Description
Recreate a dataset from a survfit object
Usage
dataset_from_survfit(fit)
Arguments
fit |
A survfit object from the 'survival' package. |
Value
The data.frame with variables: time, status, and strata (if applicable).
Examples
fit = survival::survfit(survival::Surv(time, status) ~ sex, data = survival::lung)
dataset_from_survfit(fit)
Plot and adjusted Kaplan-Meier curve accounting for landmark analysis
Description
Plot and adjusted Kaplan-Meier curve accounting for landmark analysis
Usage
ggsurvplotlm(fit, landmark_time = 6, landmark_label = "Landmark Time", ...)
Arguments
fit |
A survfit object from the 'survival' package. |
landmark_time |
The time at which to perform the landmark analysis |
landmark_label |
The label to use for the landmark time in the plot |
... |
Additional arguments passed to [survminer::ggsurvplot()]. |
Value
The modified ggsurvplot object.
Examples
fit = survival::survfit(survival::Surv(time, status) ~ sex, data = survival::lung)
ggsurvplotlm(fit, landmark_time = 70, landmark_label = "Landmark Time",axes.offset=FALSE)